==> kleandisk-2.0beta2.tar.gz: kleandisk-2.0beta2/kleandisk/ins.cpp <==
/***************************************************************************
                          ins.cpp  -  description
                             -------------------
    begin                : Sun Nov 12 2000
    copyright            : (C) 2000 by Arjan Buursink
    email                : buursink@casema.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "ins.h"

#include <qtextstream.h>
#include "info.h"

INS::INS(QString s){
	bfn = s;
	setName(s);
	setType(TYPE_INS);
	setDescription("This group is intalled by invoking 'make install'");
}

INS::~INS(){
}

void INS::loadFiles(){
	unloadFiles();
	QFile f(insDir() + baseFileName() + ".files");
	if (f.open(IO_ReadOnly)){
		QTextStream t(&f);
		QString file;
		while (!t.eof()){
			file = t.readLine();
			addFileFast(file);
			QFileInfo fi(file);
			if (fi.permission(QFileInfo::ExeUser)){ // Do not use isExecutable(), seems bug in qt in case of root
				setName(fi.baseName());
				setIcon(fi.baseName());
			}
		}	
		f.close();
	}
	sync();
}

ABProcess * INS::unInstall(){
	ABProcess * p = new ABProcess("rm");
	*p << "rm";
	*p << "-vf";
	for (unsigned int i = 0; i< numFiles(); i++)
		*p << file(i);
	return p;
}

==> kleandisk-2.1beta2.tar.gz: kleandisk-2.1beta2/kleandisk/ins.cpp <==
/***************************************************************************
                          ins.cpp  -  description
                             -------------------
    begin                : Sun Nov 12 2000
    copyright            : (C) 2000 by Arjan Buursink
    email                : buursink@casema.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "ins.h"

#include <qtextstream.h>
#include <ksimpleconfig.h>
#include "info.h"

INS::INS(QString s){
	bfn = s;
	setName(s);
	setType(TYPE_INS);
	setDescription("This group is intalled by invoking 'make install'");
}

INS::~INS(){
}

void INS::loadFiles(){
	unloadFiles();
	QFile f(insDir() + baseFileName() + ".files");
	if (f.open(IO_ReadOnly)){
		QTextStream t(&f);
		QString file;
		while (!t.eof()){
			file = t.readLine();
			addFileFast(file);
			if (file.right(8) == ".desktop"){
				KSimpleConfig cfg(file);
				cfg.setDesktopGroup();
				setName(cfg.readEntry("Name") + " (" + baseFileName() + ")");
				if (cfg.readEntry("MiniIcon").length() > 0)
					setIcon(cfg.readEntry("MiniIcon"));
				else
					setIcon(cfg.readEntry("Icon"));
				setDescription(cfg.readEntry("Comment"));
			}
		}	
		f.close();
	}
	sync();
}

ABProcess * INS::unInstall(){
	ABProcess * p = new ABProcess();
	*p << "rm";
	*p << "-vf";
	for (unsigned int i = 0; i< numFiles(); i++)
		*p << file(i);
	return p;
}
